@@ -127,6 +127,7 @@ import           Control.Monad.RWS.Strict (ask)
 import           Control.Monad.State      (gets)
 import           Data.Char                (isDigit, isHexDigit, isOctDigit, isSpace, isUpper, toLower, toUpper)
 import           Data.List                (intersperse, sort)
+import           Data.List.NonEmpty       (NonEmpty(..))
 import           Data.Maybe               (catMaybes, fromMaybe, listToMaybe)
 import           Data.Monoid              ((<>))
 import qualified Data.Set                 as Set
@@ -586,10 +587,13 @@ scrollCursorToTopB = do
 -- | Move cursor to the bottom of the screen
 scrollCursorToBottomB :: BufferM ()
 scrollCursorToBottomB = do
-    MarkSet _ i _ <- markLines
-    r <- winRegionB
-    t <- lineOf (regionEnd r - 1)
-    scrollB $ i - t
+    -- NOTE: This is only an approximation.
+    --       The correct scroll amount depends on how many lines just above
+    --       the current viewport are going to be wrapped. We don't have this
+    --       information here as wrapping is done in the frontend.
+    MarkSet f i _ <- markLines
+    h <- askWindow actualLines
+    scrollB $ i - f - h + 1
 
 -- | Scroll by n lines.
 scrollB :: Int -> BufferM ()
@@ -604,15 +608,17 @@ scrollB n = do
 
 -- Scroll line above window to the bottom.
 scrollToLineAboveWindowB :: BufferM ()
-scrollToLineAboveWindowB = do downFromTosB 0
-                              replicateM_ 1 lineUp
-                              scrollCursorToBottomB
+scrollToLineAboveWindowB = do
+    downFromTosB 0
+    replicateM_ 1 lineUp
+    scrollCursorToBottomB
 
 -- Scroll line below window to the top.
 scrollToLineBelowWindowB :: BufferM ()
-scrollToLineBelowWindowB = do upFromBosB 0
-                              replicateM_ 1 lineDown
-                              scrollCursorToTopB
+scrollToLineBelowWindowB = do
+    upFromBosB 0
+    replicateM_ 1 lineDown
+    scrollCursorToTopB
 
 -- | Move the point to inside the viewable region
 snapInsB :: BufferM ()
@@ -628,7 +634,7 @@ snapInsB = do
 indexOfSolAbove :: Int -> BufferM Point
 indexOfSolAbove n = pointAt $ gotoLnFrom (negate n)
 
-data  RelPosition = Above | Below | Within
+data RelPosition = Above | Below | Within
   deriving (Show)
 
 -- | return relative position of the point @p@
@@ -641,7 +647,7 @@ pointScreenRelPosition p rs re
 pointScreenRelPosition _ _ _ = Within -- just to disable the non-exhaustive pattern match warning
 
 -- | Move the visible region to include the point
-snapScreenB :: Maybe ScrollStyle ->BufferM Bool
+snapScreenB :: Maybe ScrollStyle -> BufferM Bool
 snapScreenB style = do
     w <- askWindow wkey
     movePoint <- Set.member w <$> use pointFollowsWindowA
@@ -854,11 +860,10 @@ sortLinesWithRegion region = modifyExtendedLRegion region (onLines sort')
                   | otherwise = False
 
 -- | Helper function: revert the buffer contents to its on-disk version
-revertB :: YiString -> Maybe R.ConverterName -> UTCTime -> BufferM ()
-revertB s cn now = do
+revertB :: YiString -> UTCTime -> BufferM ()
+revertB s now = do
   r <- regionOfB Document
   replaceRegionB r s
-  encodingConverterNameA .= cn
   markSavedB now
 
 -- get lengths of parts covered by block region
@@ -957,30 +962,33 @@ rightEdgesOfRegionB _ reg = savingPointB $ do
 splitBlockRegionToContiguousSubRegionsB :: Region -> BufferM [Region]
 splitBlockRegionToContiguousSubRegionsB reg = savingPointB $ do
     (start, lengths) <- shapeOfBlockRegionB reg
-    moveTo start
-    forM lengths $ \l -> do
+    forM (zip [0..] lengths) $ \(i, l) -> do
+        moveTo start
+        void $ lineMoveRel i
         p0 <- pointB
         moveXorEol l
         p1 <- pointB
         let subRegion = mkRegion p0 p1
-        moveTo p0
-        void $ lineMoveRel 1
         return subRegion
 
-deleteRegionWithStyleB :: Region -> RegionStyle -> BufferM Point
+-- Return list containing a single point for all non-block styles.
+-- For Block return all the points along the left edge of the region
+deleteRegionWithStyleB :: Region -> RegionStyle -> BufferM (NonEmpty Point)
 deleteRegionWithStyleB reg Block = savingPointB $ do
     (start, lengths) <- shapeOfBlockRegionB reg
     moveTo start
-    forM_ (zip [1..] lengths) $ \(i, l) -> do
+    points <- forM (zip [1..] lengths) $ \(i, l) -> do
         deleteN l
+        p <- pointB
         moveTo start
         lineMoveRel i
-    return start
+        return (if l == 0 then Nothing else Just p)
+    return $ start :| drop 1 (catMaybes points)
 
 deleteRegionWithStyleB reg style = savingPointB $ do
     effectiveRegion <- convertRegionToStyleB reg style
     deleteRegionB effectiveRegion
-    return $! regionStart effectiveRegion
+    return $! pure (regionStart effectiveRegion)
 
 readRegionRopeWithStyleB :: Region -> RegionStyle -> BufferM YiString
 readRegionRopeWithStyleB reg Block = savingPointB $ do
