@@ -136,7 +136,6 @@ module Yi.Buffer.Misc
   , modePrettifyA
   , modeKeymapA
   , modeIndentA
-  , modeAdjustBlockA
   , modeFollowA
   , modeIndentSettingsA
   , modeToggleCommentSelectionA
@@ -192,7 +191,6 @@ module Yi.Buffer.Misc
   , increaseFontSize
   , indentSettingsB
   , fontsizeVariationA
-  , encodingConverterNameA
   , stickyEolA
   , queryBuffer
   ) where
@@ -362,9 +360,6 @@ defaultModeLine prefix = do
     ro <-use readOnlyA
     modeNm <- gets (withMode0 modeName)
     unchanged <- gets isUnchangedBuffer
-    enc <- use encodingConverterNameA >>= return . \case
-      Nothing -> mempty :: T.Text
-      Just cn -> T.pack $ R.unCn cn
     let pct
           | pos == 0 || s == 0 = " Top"
           | pos == s = " Bot"
@@ -376,7 +371,7 @@ defaultModeLine prefix = do
         toT = T.pack . show
 
     nm <- gets $ shortIdentString (length prefix)
-    return $ T.concat [ enc, " ", readOnly', changed, " ", nm
+    return $ T.concat [ readOnly', changed, " ", nm
                       , "     ", hexChar, "  "
                       , "L", T.justifyRight 5 ' ' (toT ln)
                       , "  "
@@ -483,8 +478,9 @@ runBufferDummyWindow b = fst . runBuffer (dummyWindow $ bkey b) b
 
 -- | Mark the current point in the undo list as a saved state.
 markSavedB :: UTCTime -> BufferM ()
-markSavedB t = do undosA %= setSavedFilePointU
-                  lastSyncTimeA .= t
+markSavedB t = do
+    undosA %= setSavedFilePointU
+    lastSyncTimeA .= t
 
 bkey :: FBuffer -> BufferRef
 bkey = view bkey__A
@@ -495,9 +491,7 @@ isUnchangedBuffer = isAtSavedFilePointU . view undosA
 startUpdateTransactionB :: BufferM ()
 startUpdateTransactionB = do
   transactionPresent <- use updateTransactionInFlightA
-  if transactionPresent
-  then error "Already started update transaction"
-  else do
+  when (not transactionPresent) $ do
     undosA %= addChangeU InteractivePoint
     updateTransactionInFlightA .= True
 
@@ -573,7 +567,6 @@ emptyMode = Mode
    modePrettify = const $ return (),
    modeKeymap = id,
    modeIndent = \_ _ -> return (),
-   modeAdjustBlock = \_ _ -> return (),
    modeFollow = const emptyAction,
    modeIndentSettings = IndentSettings
    { expandTabs = True
@@ -613,7 +606,6 @@ newB unique nm s =
             , updateTransactionInFlight = False
             , updateTransactionAccum = mempty
             , fontsizeVariation = 0
-            , encodingConverterName = Nothing
             , updateStream = mempty
             } }
 
