@@ -71,6 +71,7 @@ module Yi.Interact
 import           Control.Applicative (Alternative ((<|>), empty))
 import           Control.Arrow       (first)
 import           Lens.Micro.Platform          (_1, _2, view)
+import qualified Control.Monad.Fail as Fail
 import           Control.Monad.State (MonadPlus (..), MonadTrans (lift), StateT)
 import           Data.Function       (on)
 import           Data.List           (groupBy)
@@ -126,8 +127,13 @@ instance Alternative (I ev w) where
 
 instance Monad (I event w) where
   return  = Returns
-  fail _  = Fails
   (>>=)   = Binds
+#if (!MIN_VERSION_base(4,13,0))
+  fail _ = Fails
+#endif
+
+instance Fail.MonadFail (I event w) where
+  fail _  = Fails
 
 instance Eq w => MonadPlus (I event w) where
   mzero = Fails
@@ -294,7 +300,7 @@ instance (Show w, Show ev) => Show (P ev w) where
 
 -- ---------------------------------------------------------------------------
 -- Derived operations
-oneOf :: (Ord event, MonadInteract m w event) => [event] -> m event
+oneOf :: (Ord event, MonadInteract m w event, Fail.MonadFail m) => [event] -> m event
 oneOf s = choice $ map event s
 
 anyEvent :: (Ord event, MonadInteract m w event) => m event
@@ -311,7 +317,7 @@ events :: (Ord event, MonadInteract m w event) => [event] -> m [event]
 -- ^ Parses and returns the specified list of events (lazily).
 events = mapM event
 
-choice :: (MonadInteract m w e) => [m a] -> m a
+choice :: (MonadInteract m w e, Fail.MonadFail m) => [m a] -> m a
 -- ^ Combines all parsers in the specified list.
 choice []     = fail "No choice succeeds"
 choice [p]    = p
